@@ -362,12 +362,12 @@ class ListingResource:
 
         return Response[Listing](**json)
      
-    async def aget_listings_by_listing_ids(self, listing_ids: List[int], includes: str = ""):
+    async def aget_listings_by_listing_ids(self, session: AsyncOauth2Session, listing_ids: List[int], includes: str = ""):
         params = {
             "listing_ids":",".join(list(map(str, listing_ids))),
             "includes":includes
         }
         endpoint = "listings/batch"
         
-        response = await self.session.async_request(endpoint, params=params)
+        response = await self.session.async_request(endpoint, session=session, params=params)
         return Response[Listing](**response)
\ No newline at end of file
